@@ -29,7 +29,7 @@ return_type_t<T_rate> poisson_lcdf(const T_n& n, const T_rate& lambda) {
   using T_partials_return = partials_return_t<T_n, T_rate>;
   using T_n_ref = ref_type_if_not_constant_t<T_n>;
   using T_lambda_ref = ref_type_if_not_constant_t<T_rate>;
-  static const char* function = "poisson_lcdf";
+  static constexpr const char* function = "poisson_lcdf";
   check_consistent_sizes(function, "Random variable", n, "Rate parameter",
                          lambda);
 
